@@ -16,16 +16,8 @@ API Documentaton v2: https://t3n.zendesk.com/categories/20067994-API-v2-0-Beta-
 
 """
 
-from clc.shell import Args, ExecCommand
-from clc.account import Account
-from clc.user import User
-from clc.group import Group
-from clc.server import Server
-from clc.network import Network
-from clc.billing import Billing
-from clc.queue import Queue
-from clc.blueprint import Blueprint
-from clc.api import API
+import APIv1 as v1
+import APIv1 as v2
 import defaults
 
 
@@ -43,6 +35,8 @@ args = False
 _LOGIN_COOKIE_V1 = False
 _LOGIN_TOKEN_V2 = False
 
+_V1_ENABLED = False
+_V2_ENABLED = False
 _LOGINS = 0
 _BLUEPRINT_FTP_URL = False
 
@@ -52,6 +46,10 @@ LOCATIONS = ['CA1','CA2','CA3','DE1','GB1','GB3','IL1','NY1','UC1','UT1','VA1','
 
 class CLCException(Exception):
 	pass
+class APIV1NotEnabled(CLCException):
+	pass
+class APIV2NotEnabled(CLCException):
+	pass
 class AccountDoesNotExistException(CLCException):
 	pass
 class AccountDeletedException(CLCException):
@@ -59,26 +57,3 @@ class AccountDeletedException(CLCException):
 class AccountLoginException(CLCException):
     pass
 
-
-class output:
-	
-	@staticmethod
-	def Status(status,level,message):
-		pass
-
-
-def SetCredentialsV1(api_key,api_passwd):
-	"""Establish API key and password associated with APIv1 commands."""
-	global V1_API_KEY
-	global V1_API_PASSWD
-	V1_API_KEY = api_key
-	V1_API_PASSWD = api_passwd
-
-
-def SetCredentialsV2(api_username,api_passwd):
-	"""Establish API username and password associated with APIv2 commands."""
-	global V2_API_USERNAME
-	global V2_API_PASSWD
-	V2_API_USERNAME = api_username
-	V2_API_PASSWD = api_passwd
-
